@@ -7,7 +7,7 @@ use Test::Builder;
 use base qw(Exporter);
 
 use vars qw($VERSION @EXPORT);
-$VERSION = '0.07';
+$VERSION = '0.09';
 @EXPORT = qw(dies_ok lives_ok throws_ok);
 
 my $Tester = Test::Builder->new;
@@ -17,21 +17,20 @@ my $Tester = Test::Builder->new;
 
 Test::Exception - Convenience routines for testing exception based code
 
-
 =head1 SYNOPSIS
 
   use Test::More tests => 4;
   use Test::Exception;
-  
+
   # Check that something died
   dies_ok {$foo->method1} 'expecting to die';
-  
+
   # Check that something did not die
   lives_ok {$foo->method2} 'expecting to live';
-  
+
   # Check that the stringified exception matches given regex
   throws_ok {$foo->method3} qr/division by zero/, 'zero caught okay';
-  
+
   # Check an exception of the given class (or subclass) is thrown
   throws_ok {$foo->method4} 'Error::Simple', 'simple error thrown';
 
@@ -54,14 +53,14 @@ Tests to see that BLOCK exits by dying, rather than by exiting normally. For exa
         my ($a, $b) = @_;
         return( $a / $b );
     };
-    
+
     dies_ok { div(1, 0) } 'divide by zero detected';
 
 A true value is returned if the test succeeds, false otherwise. $@ is guaranteed to be the cause of death (if any).
 
 The test name is optional, but recommended. 
 
-    
+
 =cut
 
 sub dies_ok (&@) {
@@ -86,10 +85,10 @@ Tests to see that BLOCK exits normally, and doesn't die. For example:
         close(FILE);
         return($file);
     };
-    
+
     my $file;
     lives_ok { $file = read_file('test.txt') } 'file read';
-    
+
 Should a C<lives_ok> test fail it produces appropriate diagnostic messages. For example:
 
     not ok 1 - file read
@@ -125,24 +124,26 @@ In the first form the test passes if the stringified exception matches the give
     throws_ok { 
         read_file('test.txt') 
     } qr/No such file/, 'no file';
-    
+
 If your perl does not support C<qr//> you can also pass a regex-like string, for example:
-    
+
     throws_ok { 
         read_file('/etc/kcpassword') 
     } '/Permission denied/', 'no permissions';
 
+I<NOTE:> Any line in the exception containing the string C<Test::Exception::throws_ok(> is ignored by the regex. Otherwise tests on exceptions that includes a stacktrace can match because the regex appears in the stacktrace as an argument to throws_ok.
+
 The second form of throws_ok test passes if the exception is of the same class as the one supplied, or a subclass of that class. For example:
 
     throws_ok {$foo->bar} "Error::Simple", 'simple error';
-	
+
 Will only pass if the C<bar> method throws an Error::Simple exception, or a subclass of an Error::Simple exception.
 
 You can get the same effect by passing an instance of the exception you want to look for. The following is equivalent to the previous example:
 
     my $SIMPLE = Error::Simple->new();
     throws_ok {$foo->bar} $SIMPLE, 'simple error';
-	
+
 Should a C<throws_ok> test fail it produces appropriate diagnostic messages. For example:
 
     not ok 3 - simple error
@@ -164,7 +165,9 @@ sub throws_ok (&@) {
 	unless (defined($exception) && $exception eq '') {
 		my $regex;
 		if ($regex = $Tester->maybe_regex($class)) {
-			$ok = ($exception =~ m/$regex/);
+			my $string = $exception;
+			$string =~ s/^.*\QTest::Exception::throws_ok(\E.*$//mg;
+			$ok = ($string =~ m/$regex/);
 		} elsif (ref($exception)) {
 			$class = ref($class) if ref($class);
 			$ok = UNIVERSAL::isa($exception, $class);
@@ -172,11 +175,7 @@ sub throws_ok (&@) {
 	};
 	$Tester->ok($ok, $message);
 	unless ($ok) {
-		if (defined($exception)) {
-			$exception = 'normal exit' if $exception eq '';
-		} else {
-			$exception = 'undef';
-		};
+		$exception = 'normal exit' if $exception eq '';
 		$class = 'undef' unless defined($class);
 		$class .= " exception" unless ref($class);
 		$Tester->diag("expecting: $class");
@@ -205,16 +204,23 @@ If you think this module should do something that it doesn't do at the moment pl
 
 =head1 SEE ALSO
 
+
+L<Test::Builder> provides a consistent backend for building test libraries. The following modules are all built with L<Test::Builder> and work well together.
+
 =over 4
 
-=item L<Test::Builder>, L<Test::Simple> and L<Test::More>
+=item L<Test::Simple> & L<Test::More>
 
-Framework for creating test libraries and scripts.
+Basic utilities for writing tests.
 
-=item L<Test::Difference>
+=item L<Test::Differences>
 
 Test strings and data structures and show differences if not ok.
 
+=item L<Test::Inline>
+
+Inlining your tests next to the code being tested.
+
 =back
 
 
@@ -227,7 +233,9 @@ If you can spare the time, please drop me a line if you find this module useful.
 
 =head1 ACKNOWLEGEMENTS
 
-Thanks to Michael G Schwern and Mark Fowler for suggestions.
+Thanks to Michael G Schwern and Mark Fowler for suggestions and comments on initial versions of this module.
+
+This module wouldn't be possible without the excellent Test::Builder. Thanks to chromatic <chromatic@wgz.org> and Michael G Schwern <schwern@pobox.com> for creating such a useful module.
 
 
 =head1 LICENCE
